@@ -1,18 +1,17 @@
 import asyncio
 import itertools
+from random import random
 import time
-from typing import Sequence, Union
+from typing import Optional, Sequence, Union
+
+from .typing import FloatLike
 
 
 __all__ = ['RetryDelayer']
 
 
-FloatLike = Union[int, float]
-
-
 class RetryDelayer:
-    """
-    Usage example:
+    """Usage example:
 
         retry_delayer = async_plus.RetryDelayer()
         while True:
@@ -36,12 +35,16 @@ class RetryDelayer:
     def __init__(
         self,
         delays: Sequence[FloatLike] = (0, 1, 10, 60),
-        reset_after: FloatLike = None,
+        random_shift: FloatLike = 0,
+        reset_after: Optional[FloatLike] = None,
     ):
         self.delays = delays
+        self.random_shift = random_shift
+
         if reset_after is None:
             reset_after = delays[-1]
         self.reset_after = reset_after
+
         self.reset()
 
     def reset(self):
@@ -53,6 +56,10 @@ class RetryDelayer:
     async def sleep(self):
         if time.monotonic() - self._last_time > self.reset_after:
             self.reset()
+
         delay = next(self._iter_delays)
+        if self.random_shift:
+            delay += self.random_shift * random()
         await asyncio.sleep(delay)
+
         self._last_time = time.monotonic()
