@@ -41,3 +41,31 @@ async def test_full_cycle(reset_after):
                 await delayer.sleep()
                 sleep_mock.assert_awaited_once_with(expected_sleep)
 
+
+@pytest.mark.skipif(
+    sys.version_info < (3, 8),
+    reason='author is too lazy to backport test',
+)
+async def test_random_shift():
+    delayer = async_plus.RetryDelayer([3], random_shift=2)
+
+    def shift_monotonic(secs):
+        monotonic_mock.return_value += secs
+
+    with mock.patch.object(time, 'monotonic') as monotonic_mock, \
+            mock.patch.object(
+                asyncio, 'sleep', side_effect=shift_monotonic,
+            ) as sleep_mock:
+        monotonic_mock.return_value = 0
+
+        COUNT = 1_000
+        shifts = 0
+        for i in range(COUNT):
+            await delayer.sleep()
+            assert sleep_mock.await_count == i + 1
+            (delay,) = sleep_mock.await_args.args
+            assert 3 <= delay < 5
+            shifts += delay - 3
+
+        avg_shift = shifts / COUNT
+        assert 0.9 < avg_shift < 1.1
